# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import antenny
from antenny.api.subscription_api import SubscriptionApi  # noqa: E501
from antenny.rest import ApiException


class TestSubscriptionApi(unittest.TestCase):
    """SubscriptionApi unit test stubs"""

    def setUp(self):
        self.api = antenny.api.subscription_api.SubscriptionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_subscription(self):
        """Test case for cancel_subscription

        Cancels a subscription  # noqa: E501
        """
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Creates a subscription  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Gets a subscription  # noqa: E501
        """
        pass

    def test_list_subscriptions(self):
        """Test case for list_subscriptions

        Gets a list of subscriptions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
