# coding: utf-8

"""
    Antenny API

    This is an api that allows you to interact with the Antenny platform. It allows you to manage your clients and subscriptions.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: admin@antenny.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from antenny.configuration import Configuration


class EventList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': 'list[Event]',
        'last_key': 'str'
    }

    attribute_map = {
        'items': 'items',
        'last_key': 'lastKey'
    }

    def __init__(self, items=None, last_key=None, local_vars_configuration=None):  # noqa: E501
        """EventList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._last_key = None
        self.discriminator = None

        if items is not None:
            self.items = items
        self.last_key = last_key

    @property
    def items(self):
        """Gets the items of this EventList.  # noqa: E501


        :return: The items of this EventList.  # noqa: E501
        :rtype: list[Event]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this EventList.


        :param items: The items of this EventList.  # noqa: E501
        :type items: list[Event]
        """

        self._items = items

    @property
    def last_key(self):
        """Gets the last_key of this EventList.  # noqa: E501


        :return: The last_key of this EventList.  # noqa: E501
        :rtype: str
        """
        return self._last_key

    @last_key.setter
    def last_key(self, last_key):
        """Sets the last_key of this EventList.


        :param last_key: The last_key of this EventList.  # noqa: E501
        :type last_key: str
        """

        self._last_key = last_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventList):
            return True

        return self.to_dict() != other.to_dict()
